@@ -81,7 +81,7 @@ class HotMapNavigator(object):
 class SquareMap( wx.Panel ):
     """Construct a nested-box trees structure view"""
 
-    BackgroundColor = wx.Colour( 128,128,128 )
+    BackgroundColour = wx.Colour( 128,128,128 )
     max_depth = None
     max_depth_seen = None
 
@@ -164,7 +164,7 @@ class SquareMap( wx.Panel ):
 
         try:
             parent, children, index = HotMapNavigator.findNode(self.hot_map, self.selectedNode)
-        except TypeError, err:
+        except TypeError:
             log.info( 'Unable to find hot-map record for node %s', self.selectedNode )
         else:
             if event.KeyCode == wx.WXK_DOWN:
@@ -214,9 +214,11 @@ class SquareMap( wx.Panel ):
     def OnSize(self, event):
         # The buffer is initialized in here, so that the buffer is always
         # the same size as the Window.
+        if event is None:
+            return 0,0
         width, height = self.GetClientSizeTuple()
         if width <= 0 or height <=0:
-            return
+            return 0,0
         # Make new off-screen bitmap: this bitmap will always have the
         # current drawing in it, so it can be used to save the image to
         # a file, or whatever.
@@ -255,17 +257,17 @@ class SquareMap( wx.Panel ):
     def BrushForNode( self, node, depth=0 ):
         """Create brush to use to display the given node"""
         if node == self.selectedNode:
-            color = wx.SystemSettings_GetColour(wx.SYS_COLOUR_HIGHLIGHT)
+            colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_HIGHLIGHT)
         elif node == self.highlightedNode:
-            color = wx.Colour( red=0, green=255, blue=0 )
+            colour = wx.Colour( red=0, green=255, blue=0 )
         else:
-            color = self.adapter.background_color(node, depth)
-            if not color:
+            colour = self.adapter.background_color(node, depth)
+            if not colour:
                 red = (depth * 10)%255
                 green = 255-((depth * 5)%255)
                 blue = (depth * 25)%255
-                color = wx.Colour( red, green, blue )
-        return wx.Brush( color  )
+                colour = wx.Colour( red, green, blue )
+        return wx.Brush( colour  )
 
     def PenForNode( self, node, depth=0 ):
         """Determine the pen to use to display the given node"""
@@ -274,15 +276,15 @@ class SquareMap( wx.Panel ):
         return self.DEFAULT_PEN
 
     def TextForegroundForNode(self, node, depth=0):
-        """Determine the text foreground color to use to display the label of
+        """Determine the text foreground colour to use to display the label of
            the given node"""
         if node == self.selectedNode:
-            fg_color = wx.SystemSettings_GetColour(wx.SYS_COLOUR_HIGHLIGHTTEXT)
+            fg_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_HIGHLIGHTTEXT)
         else:
-            fg_color = self.adapter.foreground_color(node, depth)
-            if not fg_color:
-                fg_color = wx.SystemSettings_GetColour(wx.SYS_COLOUR_WINDOWTEXT)
-        return fg_color
+            fg_colour = self.adapter.foreground_color(node, depth)
+            if not fg_colour:
+                fg_colour = wx.SystemSettings_GetColour(wx.SYS_COLOUR_WINDOWTEXT)
+        return fg_colour
 
     def DrawBox( self, dc, node, x,y,w,h, hot_map, depth=0 ):
         """Draw a model-node's box and all children nodes"""
@@ -397,7 +399,7 @@ class SquareMap( wx.Panel ):
             if head_coord:
                 self.DrawBox( 
                     dc, firstNode, head_coord[0],head_coord[1],head_coord[2],head_coord[3], 
-                    hot_map, depth+1 
+                    hot_map, depth
                 )
             else:
                 return # no other node will show up as non-0 either
@@ -524,7 +526,7 @@ usage = 'squaremap.py somedirectory'
 def main():
     """Mainloop for the application"""
     if not sys.argv[1:]:
-        print usage
+        print(usage)
     else:
         app = TestApp(0)
         app.MainLoop()
